@@ -35,7 +35,7 @@ class ModelTorchAdapter(Model):
 
     def prepareDataAdapter(self, datasetOrTuple, validation=False):
         x, y = datasetOrTuple
-        
+
         if not torch.is_tensor(x):
             x = torch.tensor(x)
         if not torch.is_tensor(y):
@@ -65,9 +65,10 @@ class ModelTorchAdapter(Model):
         validationData.transformToCategorical = 0
         batchCount = len(validationData)
         processList = tqdm(range(batchCount), disable=(not self.showProgress))
-        processList.set_description("Validation")       
+        processList.set_description("Validation")
         batchGenerator = validationData.generator()
 
+        iter(validationData)
         for batchIndex in processList:
             validationBatch = batchGenerator.__next__()
             x, y = self.prepareDataAdapter(validationBatch, validation=True)
@@ -125,20 +126,18 @@ class ModelTorchAdapter(Model):
         return targets.float(), mask
 
     def train(self, dataset: TrainingSet):
-        
+
         if ModelTorchAdapter.useTensorBoard:
             from torch.utils.tensorboard import SummaryWriter
+
             self.summarywriter = SummaryWriter()
-            
+
             for (f, title) in self.startFigures:
                 self.summarywriter.add_figure(title, f)
         else:
             self.summarywriter = None
         self.cleanCsv()
 
-        if self.oneHotDecoded:
-            dataset.trainingData.transformToCategorical = self.numClasses
-
         metricDefinitions = {
             # init value, useAsBest, biggerIsBetter
             "AUC": [0.5, False, True],
@@ -188,11 +187,11 @@ class ModelTorchAdapter(Model):
             model.train(True)
             runningStats = {"loss": 0.0}
             batchesPerEpoch = len(dataset.trainingData)
-            dataset.trainingData.continous = False
             processList = tqdm(range(batchesPerEpoch), disable=(not self.showProgress))
             processList.set_description("EPOCH {}".format(i_epoch))
             batchGenerator = dataset.trainingData.generator()
 
+            iter(dataset.trainingData)
             for batchIndex in processList:
                 trainBatch = next(batchGenerator)
                 batchFeats, targs = self.prepareDataAdapter(trainBatch)
@@ -259,7 +258,7 @@ class ModelTorchAdapter(Model):
                 metricStrings.append(metricName + ": " + "{:.3f}".format(metricVal) + " [best: {:.3f}]".format(bestValue))
                 metricDiffStrings.append(metricName + ": " + "{:.3f}".format(diff))
                 metricValuetrings.append("{:.3f}".format(metricVal))
-                
+
                 if self.summarywriter is not None:
                     self.summarywriter.add_scalar(metricName, metricVal, global_step=self.fullEpochs)
 
@@ -307,7 +306,10 @@ class ModelTorchAdapter(Model):
             # If the validation accuracy improves, print out training and validation accuracy values and checkpoint the model
             if improved:
                 self.log("Model Improved: " + " ".join(metricDiffStrings))
-                f = open(self.getModelPath() + "/" + modelId + "_".join(metricValuetrings) + ".pkl", "wb")
+                f = open(
+                    self.getModelPath() + "/" + modelId + "_".join(metricValuetrings) + ".pkl",
+                    "wb",
+                )
                 # self.trigger("modelImproved", model)
                 torch.save(model, f)
                 f.close()
