@@ -10,9 +10,11 @@ from ..Model import Model
 
 if importlib.util.find_spec("torch"):
     import torch
-    
+
     if importlib.util.find_spec("tensorflow"):
-        print(u"\033[31;1;4m%s\033[0mTensorflow and PyTorch are installed in the same enviroment, only one model (PyTorch) can be exported/imported")
+        print(
+            u"\033[31;1;4m%s\033[0mTensorflow and PyTorch are installed in the same enviroment, only one model (PyTorch) can be exported/imported"
+        )
 
     class ModelExporter(DataExporter):
         includesStorage = True
@@ -71,16 +73,20 @@ elif importlib.util.find_spec("tensorflow"):
 
         def write(self, dataId, model, options={}):
             model.save_weights(self.getPath(dataId))
+
+
 else:
     # ability to ignore missing model exporter for testing purposes
     if os.environ.get("PYPHASESML_IGNORE_MISSING_MODEL_EXPORTER", 0) == 1:
         raise Exception("No supported ModelExporter located (Supported: pytorch/tensorflow)")
     else:
+
+
         class ModelExporter(DataExporter):
             includesStorage = True
 
             def checkType(self, expectedType):
-                raise Exception("ModelExporter is only as stub, please install tensorflow or pytorch to use the ModelExporter")
+                return False
 
             def read(self, path, data, options={}):
                 raise Exception("ModelExporter is only as stub, please install tensorflow or pytorch to use the ModelExporter")
